==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesCbk_zam.php <==
<?php
/** Chavacano de Zamboanga (Chavacano de Zamboanga)
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = "es";

$messages = array(
'help'           => 'Ayuda',
'search'         => 'Busqueda',
'history_short'  => 'Historia',
'edit'           => 'revisa',
'delete'         => 'Bora',
'articlepage'    => 'Mira con el contenido del pagina',
'otherlanguages' => 'na otro maga lenguaje',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage' => 'El Primero Pagina',
'portal'   => 'Portal del Comunidad',

# Login and logout pages
'acct_creation_throttle_hit' => 'Pasencia. Ya crea ya tu $1 maga cuenta. No puede mas tu rehistra pa otra vez.',
'accountcreated'             => 'El rehistro cuenta de usario es creando',
'accountcreatedtext'         => 'El cuenta por usario $1 ya crea ya.',

# Edit pages
'blockedtitle' => 'El usario es prohibido',
'accmailtitle' => 'El contraseña imbiao ya.',
'accmailtext'  => 'El contraseña por "$1" ya imbia ya para con $2.',

# Preferences page
'changepassword' => 'Cambia con el contraseña',

# Recent changes
'recentchanges' => 'Maga Reciente Cambio',

# Random page
'randompage' => 'Pagina Escujido Automatico',

# Special:Allpages
'allarticles' => 'Todo maga articulo',

# Watchlist
'watch' => 'Vicia',

'changed' => 'cambiao',
'created' => 'creao',

# Delete/protect/revert
'actioncomplete' => 'Accion completo',

# Block/unblock
'blockip'           => 'Prohibi con el usario',
'blockipsuccesssub' => 'El prohibicion es confirmado',

# AJAX search
'articletitles' => "Maga articulo que ta prinsipa con ''$1''",

);

==> mediawiki-1.14.1.tbz: www/mediawiki/languages/messages/MessagesCbk_zam.php <==
<?php
/** Chavacano de Zamboanga (Chavacano de Zamboanga)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = "es";

$messages = array(
'help'           => 'Ayuda',
'search'         => 'Busqueda',
'history_short'  => 'Historia',
'edit'           => 'revisa',
'delete'         => 'Bora',
'articlepage'    => 'Mira con el contenido del pagina',
'otherlanguages' => 'na otro maga lenguaje',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'mainpage'             => 'El Primero Pagina',
'mainpage-description' => 'El Primero Pagina',
'portal'               => 'Portal del Comunidad',

# Login and logout pages
'acct_creation_throttle_hit' => 'Pasencia. Ya crea ya tu $1 maga cuenta. No puede mas tu rehistra pa otra vez.',
'accountcreated'             => 'El rehistro cuenta de usario es creando',
'accountcreatedtext'         => 'El cuenta por usario $1 ya crea ya.',

# Edit pages
'blockedtitle' => 'El usario es prohibido',
'accmailtitle' => 'El contraseña imbiao ya.',
'accmailtext'  => 'El contraseña por "$1" ya imbia ya para con $2.',

# Preferences page
'changepassword' => 'Cambia con el contraseña',

# Recent changes
'recentchanges' => 'Maga Reciente Cambio',

# Random page
'randompage' => 'Pagina Escujido Automatico',

# Special:AllPages
'allarticles' => 'Todo maga articulo',

# Watchlist
'watch' => 'Vicia',

'changed' => 'cambiao',
'created' => 'creao',

# Delete
'actioncomplete' => 'Accion completo',

# Block/unblock
'blockip'           => 'Prohibi con el usario',
'blockipsuccesssub' => 'El prohibicion es confirmado',

);
